"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createUseCssAndCx = void 0;
require("./tools/Object.fromEntries");
const classnames_1 = require("./tools/classnames");
const useSemanticGuaranteeMemo_1 = require("./tools/useSemanticGuaranteeMemo");
function createUseCssAndCx(params) {
    const { serializeStyles, insertStyles, getRegisteredStyles, useEmotionCache, } = params;
    function merge(registered, css, className) {
        const registeredStyles = [];
        const rawClassName = getRegisteredStyles(registered, registeredStyles, className);
        if (registeredStyles.length < 2) {
            return className;
        }
        return rawClassName + css(registeredStyles);
    }
    function useCssAndCx() {
        const cache = useEmotionCache();
        const css = useSemanticGuaranteeMemo_1.useSemanticGuaranteeMemo(() => (...args) => {
            const serialized = serializeStyles(args, cache.registered);
            insertStyles(cache, serialized, false);
            return `${cache.key}-${serialized.name}`;
        }, [cache]);
        const cx = useSemanticGuaranteeMemo_1.useSemanticGuaranteeMemo(() => (...args) => merge(cache.registered, css, classnames_1.classnames(args)), [cache]);
        return { css, cx };
    }
    return { useCssAndCx };
}
exports.createUseCssAndCx = createUseCssAndCx;
//# sourceMappingURL=createUseCssAndCx.js.map