"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDocument = exports.createGetInitialProps = exports.createPageHtmlToStyleTags = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const document_1 = __importDefault(require("next/document"));
const create_instance_1 = __importDefault(require("@emotion/server/create-instance"));
const html_react_parser_1 = __importDefault(require("html-react-parser"));
const cache_1 = require("./cache");
function createPageHtmlToStyleTags(params) {
    let { caches = [] } = params !== null && params !== void 0 ? params : {};
    {
        const cache = cache_1.getCache();
        if (!caches.includes(cache)) {
            caches = [...caches, cache];
        }
    }
    const emotionServers = caches.map(create_instance_1.default);
    function pageHtmlToStyleTags(params) {
        const { pageHtml } = params;
        return html_react_parser_1.default(emotionServers
            .map(({ extractCriticalToChunks, constructStyleTagsFromChunks, }) => {
            const { html, styles } = extractCriticalToChunks(pageHtml);
            return constructStyleTagsFromChunks({
                html,
                styles,
            });
        })
            .join(""));
    }
    return { pageHtmlToStyleTags };
}
exports.createPageHtmlToStyleTags = createPageHtmlToStyleTags;
function createGetInitialProps(params) {
    const { pageHtmlToStyleTags } = createPageHtmlToStyleTags(params);
    function getInitialProps(ctx) {
        return __awaiter(this, void 0, void 0, function* () {
            const page = yield ctx.renderPage();
            const initialProps = yield document_1.default.getInitialProps(ctx);
            return Object.assign(Object.assign({}, initialProps), { "styles": (jsx_runtime_1.jsxs(jsx_runtime_1.Fragment, { children: [initialProps.styles, pageHtmlToStyleTags({ "pageHtml": page.html })] }, void 0)) });
        });
    }
    return { getInitialProps };
}
exports.createGetInitialProps = createGetInitialProps;
function createDocument(params) {
    const { getInitialProps } = createGetInitialProps(params);
    class Document extends document_1.default {
        static getInitialProps(ctx) {
            return __awaiter(this, void 0, void 0, function* () {
                return getInitialProps(ctx);
            });
        }
    }
    return { Document };
}
exports.createDocument = createDocument;
//# sourceMappingURL=nextJs.js.map